# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InferenceDeploymentArgs', 'InferenceDeployment']

@pulumi.input_type
class InferenceDeploymentArgs:
    def __init__(__self__, *,
                 model_id: pulumi.Input[_builtins.str],
                 node_type: pulumi.Input[_builtins.str],
                 accept_eula: Optional[pulumi.Input[_builtins.bool]] = None,
                 max_size: Optional[pulumi.Input[_builtins.int]] = None,
                 min_size: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 private_endpoint: Optional[pulumi.Input['InferenceDeploymentPrivateEndpointArgs']] = None,
                 private_ips: Optional[pulumi.Input[Sequence[pulumi.Input['InferenceDeploymentPrivateIpArgs']]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public_endpoint: Optional[pulumi.Input['InferenceDeploymentPublicEndpointArgs']] = None,
                 quantization: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a InferenceDeployment resource.
        :param pulumi.Input[_builtins.str] model_id: The model id used for the deployment.
        :param pulumi.Input[_builtins.str] node_type: The node type to use for the deployment. Node types can be found using Scaleway's CLI (`scw inference node-type list`)
        :param pulumi.Input[_builtins.bool] accept_eula: Some models (e.g Meta Llama) require end-user license agreements. Set `true` to accept.
        :param pulumi.Input[_builtins.int] max_size: The maximum size of the pool.
        :param pulumi.Input[_builtins.int] min_size: The minimum size of the pool.
        :param pulumi.Input[_builtins.str] name: The deployment name.
        :param pulumi.Input['InferenceDeploymentPrivateEndpointArgs'] private_endpoint: Configuration of the deployment's private endpoint.
        :param pulumi.Input[Sequence[pulumi.Input['InferenceDeploymentPrivateIpArgs']]] private_ips: The private IPv4 address associated with the deployment.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the deployment is associated with.
        :param pulumi.Input['InferenceDeploymentPublicEndpointArgs'] public_endpoint: Configuration of the deployment's public endpoint.
        :param pulumi.Input[_builtins.int] quantization: The number of bits each model parameter should be quantized to
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the deployment is created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the deployment.
        """
        pulumi.set(__self__, "model_id", model_id)
        pulumi.set(__self__, "node_type", node_type)
        if accept_eula is not None:
            pulumi.set(__self__, "accept_eula", accept_eula)
        if max_size is not None:
            pulumi.set(__self__, "max_size", max_size)
        if min_size is not None:
            pulumi.set(__self__, "min_size", min_size)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if private_endpoint is not None:
            pulumi.set(__self__, "private_endpoint", private_endpoint)
        if private_ips is not None:
            pulumi.set(__self__, "private_ips", private_ips)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if public_endpoint is not None:
            pulumi.set(__self__, "public_endpoint", public_endpoint)
        if quantization is not None:
            pulumi.set(__self__, "quantization", quantization)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="modelId")
    def model_id(self) -> pulumi.Input[_builtins.str]:
        """
        The model id used for the deployment.
        """
        return pulumi.get(self, "model_id")

    @model_id.setter
    def model_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "model_id", value)

    @_builtins.property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> pulumi.Input[_builtins.str]:
        """
        The node type to use for the deployment. Node types can be found using Scaleway's CLI (`scw inference node-type list`)
        """
        return pulumi.get(self, "node_type")

    @node_type.setter
    def node_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "node_type", value)

    @_builtins.property
    @pulumi.getter(name="acceptEula")
    def accept_eula(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Some models (e.g Meta Llama) require end-user license agreements. Set `true` to accept.
        """
        return pulumi.get(self, "accept_eula")

    @accept_eula.setter
    def accept_eula(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "accept_eula", value)

    @_builtins.property
    @pulumi.getter(name="maxSize")
    def max_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum size of the pool.
        """
        return pulumi.get(self, "max_size")

    @max_size.setter
    def max_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_size", value)

    @_builtins.property
    @pulumi.getter(name="minSize")
    def min_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum size of the pool.
        """
        return pulumi.get(self, "min_size")

    @min_size.setter
    def min_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "min_size", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The deployment name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="privateEndpoint")
    def private_endpoint(self) -> Optional[pulumi.Input['InferenceDeploymentPrivateEndpointArgs']]:
        """
        Configuration of the deployment's private endpoint.
        """
        return pulumi.get(self, "private_endpoint")

    @private_endpoint.setter
    def private_endpoint(self, value: Optional[pulumi.Input['InferenceDeploymentPrivateEndpointArgs']]):
        pulumi.set(self, "private_endpoint", value)

    @_builtins.property
    @pulumi.getter(name="privateIps")
    def private_ips(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InferenceDeploymentPrivateIpArgs']]]]:
        """
        The private IPv4 address associated with the deployment.
        """
        return pulumi.get(self, "private_ips")

    @private_ips.setter
    def private_ips(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InferenceDeploymentPrivateIpArgs']]]]):
        pulumi.set(self, "private_ips", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the deployment is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="publicEndpoint")
    def public_endpoint(self) -> Optional[pulumi.Input['InferenceDeploymentPublicEndpointArgs']]:
        """
        Configuration of the deployment's public endpoint.
        """
        return pulumi.get(self, "public_endpoint")

    @public_endpoint.setter
    def public_endpoint(self, value: Optional[pulumi.Input['InferenceDeploymentPublicEndpointArgs']]):
        pulumi.set(self, "public_endpoint", value)

    @_builtins.property
    @pulumi.getter
    def quantization(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of bits each model parameter should be quantized to
        """
        return pulumi.get(self, "quantization")

    @quantization.setter
    def quantization(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "quantization", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the deployment is created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The tags associated with the deployment.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _InferenceDeploymentState:
    def __init__(__self__, *,
                 accept_eula: Optional[pulumi.Input[_builtins.bool]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 max_size: Optional[pulumi.Input[_builtins.int]] = None,
                 min_size: Optional[pulumi.Input[_builtins.int]] = None,
                 model_id: Optional[pulumi.Input[_builtins.str]] = None,
                 model_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_type: Optional[pulumi.Input[_builtins.str]] = None,
                 private_endpoint: Optional[pulumi.Input['InferenceDeploymentPrivateEndpointArgs']] = None,
                 private_ips: Optional[pulumi.Input[Sequence[pulumi.Input['InferenceDeploymentPrivateIpArgs']]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public_endpoint: Optional[pulumi.Input['InferenceDeploymentPublicEndpointArgs']] = None,
                 quantization: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 size: Optional[pulumi.Input[_builtins.int]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering InferenceDeployment resources.
        :param pulumi.Input[_builtins.bool] accept_eula: Some models (e.g Meta Llama) require end-user license agreements. Set `true` to accept.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the deployment.
        :param pulumi.Input[_builtins.int] max_size: The maximum size of the pool.
        :param pulumi.Input[_builtins.int] min_size: The minimum size of the pool.
        :param pulumi.Input[_builtins.str] model_id: The model id used for the deployment.
        :param pulumi.Input[_builtins.str] model_name: The model name used for the deployment. Model names can be found in Console or using Scaleway's CLI (`scw inference model list`)
        :param pulumi.Input[_builtins.str] name: The deployment name.
        :param pulumi.Input[_builtins.str] node_type: The node type to use for the deployment. Node types can be found using Scaleway's CLI (`scw inference node-type list`)
        :param pulumi.Input['InferenceDeploymentPrivateEndpointArgs'] private_endpoint: Configuration of the deployment's private endpoint.
        :param pulumi.Input[Sequence[pulumi.Input['InferenceDeploymentPrivateIpArgs']]] private_ips: The private IPv4 address associated with the deployment.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the deployment is associated with.
        :param pulumi.Input['InferenceDeploymentPublicEndpointArgs'] public_endpoint: Configuration of the deployment's public endpoint.
        :param pulumi.Input[_builtins.int] quantization: The number of bits each model parameter should be quantized to
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the deployment is created.
        :param pulumi.Input[_builtins.int] size: The size of the pool.
        :param pulumi.Input[_builtins.str] status: The status of the deployment.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the deployment.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the deployment.
        """
        if accept_eula is not None:
            pulumi.set(__self__, "accept_eula", accept_eula)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if max_size is not None:
            pulumi.set(__self__, "max_size", max_size)
        if min_size is not None:
            pulumi.set(__self__, "min_size", min_size)
        if model_id is not None:
            pulumi.set(__self__, "model_id", model_id)
        if model_name is not None:
            pulumi.set(__self__, "model_name", model_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_type is not None:
            pulumi.set(__self__, "node_type", node_type)
        if private_endpoint is not None:
            pulumi.set(__self__, "private_endpoint", private_endpoint)
        if private_ips is not None:
            pulumi.set(__self__, "private_ips", private_ips)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if public_endpoint is not None:
            pulumi.set(__self__, "public_endpoint", public_endpoint)
        if quantization is not None:
            pulumi.set(__self__, "quantization", quantization)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="acceptEula")
    def accept_eula(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Some models (e.g Meta Llama) require end-user license agreements. Set `true` to accept.
        """
        return pulumi.get(self, "accept_eula")

    @accept_eula.setter
    def accept_eula(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "accept_eula", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the creation of the deployment.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="maxSize")
    def max_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum size of the pool.
        """
        return pulumi.get(self, "max_size")

    @max_size.setter
    def max_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_size", value)

    @_builtins.property
    @pulumi.getter(name="minSize")
    def min_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum size of the pool.
        """
        return pulumi.get(self, "min_size")

    @min_size.setter
    def min_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "min_size", value)

    @_builtins.property
    @pulumi.getter(name="modelId")
    def model_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The model id used for the deployment.
        """
        return pulumi.get(self, "model_id")

    @model_id.setter
    def model_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "model_id", value)

    @_builtins.property
    @pulumi.getter(name="modelName")
    def model_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The model name used for the deployment. Model names can be found in Console or using Scaleway's CLI (`scw inference model list`)
        """
        return pulumi.get(self, "model_name")

    @model_name.setter
    def model_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "model_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The deployment name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The node type to use for the deployment. Node types can be found using Scaleway's CLI (`scw inference node-type list`)
        """
        return pulumi.get(self, "node_type")

    @node_type.setter
    def node_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "node_type", value)

    @_builtins.property
    @pulumi.getter(name="privateEndpoint")
    def private_endpoint(self) -> Optional[pulumi.Input['InferenceDeploymentPrivateEndpointArgs']]:
        """
        Configuration of the deployment's private endpoint.
        """
        return pulumi.get(self, "private_endpoint")

    @private_endpoint.setter
    def private_endpoint(self, value: Optional[pulumi.Input['InferenceDeploymentPrivateEndpointArgs']]):
        pulumi.set(self, "private_endpoint", value)

    @_builtins.property
    @pulumi.getter(name="privateIps")
    def private_ips(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InferenceDeploymentPrivateIpArgs']]]]:
        """
        The private IPv4 address associated with the deployment.
        """
        return pulumi.get(self, "private_ips")

    @private_ips.setter
    def private_ips(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InferenceDeploymentPrivateIpArgs']]]]):
        pulumi.set(self, "private_ips", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the deployment is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="publicEndpoint")
    def public_endpoint(self) -> Optional[pulumi.Input['InferenceDeploymentPublicEndpointArgs']]:
        """
        Configuration of the deployment's public endpoint.
        """
        return pulumi.get(self, "public_endpoint")

    @public_endpoint.setter
    def public_endpoint(self, value: Optional[pulumi.Input['InferenceDeploymentPublicEndpointArgs']]):
        pulumi.set(self, "public_endpoint", value)

    @_builtins.property
    @pulumi.getter
    def quantization(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of bits each model parameter should be quantized to
        """
        return pulumi.get(self, "quantization")

    @quantization.setter
    def quantization(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "quantization", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the deployment is created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The size of the pool.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "size", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the deployment.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The tags associated with the deployment.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the last update of the deployment.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)


warnings.warn("""scaleway.index/inferencedeployment.InferenceDeployment has been deprecated in favor of scaleway.inference/deployment.Deployment""", DeprecationWarning)


@pulumi.type_token("scaleway:index/inferenceDeployment:InferenceDeployment")
class InferenceDeployment(pulumi.CustomResource):
    warnings.warn("""scaleway.index/inferencedeployment.InferenceDeployment has been deprecated in favor of scaleway.inference/deployment.Deployment""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accept_eula: Optional[pulumi.Input[_builtins.bool]] = None,
                 max_size: Optional[pulumi.Input[_builtins.int]] = None,
                 min_size: Optional[pulumi.Input[_builtins.int]] = None,
                 model_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_type: Optional[pulumi.Input[_builtins.str]] = None,
                 private_endpoint: Optional[pulumi.Input[Union['InferenceDeploymentPrivateEndpointArgs', 'InferenceDeploymentPrivateEndpointArgsDict']]] = None,
                 private_ips: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InferenceDeploymentPrivateIpArgs', 'InferenceDeploymentPrivateIpArgsDict']]]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public_endpoint: Optional[pulumi.Input[Union['InferenceDeploymentPublicEndpointArgs', 'InferenceDeploymentPublicEndpointArgsDict']]] = None,
                 quantization: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Managed Inference deployments.
        For more information, see the [API documentation](https://www.scaleway.com/en/developers/api/inference/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumi_scaleway as scaleway
        import pulumiverse_scaleway as scaleway

        my_model = scaleway.inference.get_model(name="meta/llama-3.1-8b-instruct:fp8")
        deployment = scaleway.inference.Deployment("deployment",
            name="tf-inference-deployment",
            node_type="L4",
            model_name=my_model.id,
            public_endpoint={
                "is_enabled": True,
            },
            accept_eula=True)
        ```

        ## Import

        Functions can be imported using, `{region}/{id}`, as shown below:

        bash

        ```sh
        $ pulumi import scaleway:index/inferenceDeployment:InferenceDeployment deployment fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] accept_eula: Some models (e.g Meta Llama) require end-user license agreements. Set `true` to accept.
        :param pulumi.Input[_builtins.int] max_size: The maximum size of the pool.
        :param pulumi.Input[_builtins.int] min_size: The minimum size of the pool.
        :param pulumi.Input[_builtins.str] model_id: The model id used for the deployment.
        :param pulumi.Input[_builtins.str] name: The deployment name.
        :param pulumi.Input[_builtins.str] node_type: The node type to use for the deployment. Node types can be found using Scaleway's CLI (`scw inference node-type list`)
        :param pulumi.Input[Union['InferenceDeploymentPrivateEndpointArgs', 'InferenceDeploymentPrivateEndpointArgsDict']] private_endpoint: Configuration of the deployment's private endpoint.
        :param pulumi.Input[Sequence[pulumi.Input[Union['InferenceDeploymentPrivateIpArgs', 'InferenceDeploymentPrivateIpArgsDict']]]] private_ips: The private IPv4 address associated with the deployment.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the deployment is associated with.
        :param pulumi.Input[Union['InferenceDeploymentPublicEndpointArgs', 'InferenceDeploymentPublicEndpointArgsDict']] public_endpoint: Configuration of the deployment's public endpoint.
        :param pulumi.Input[_builtins.int] quantization: The number of bits each model parameter should be quantized to
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the deployment is created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the deployment.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InferenceDeploymentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Managed Inference deployments.
        For more information, see the [API documentation](https://www.scaleway.com/en/developers/api/inference/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumi_scaleway as scaleway
        import pulumiverse_scaleway as scaleway

        my_model = scaleway.inference.get_model(name="meta/llama-3.1-8b-instruct:fp8")
        deployment = scaleway.inference.Deployment("deployment",
            name="tf-inference-deployment",
            node_type="L4",
            model_name=my_model.id,
            public_endpoint={
                "is_enabled": True,
            },
            accept_eula=True)
        ```

        ## Import

        Functions can be imported using, `{region}/{id}`, as shown below:

        bash

        ```sh
        $ pulumi import scaleway:index/inferenceDeployment:InferenceDeployment deployment fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param InferenceDeploymentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InferenceDeploymentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accept_eula: Optional[pulumi.Input[_builtins.bool]] = None,
                 max_size: Optional[pulumi.Input[_builtins.int]] = None,
                 min_size: Optional[pulumi.Input[_builtins.int]] = None,
                 model_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_type: Optional[pulumi.Input[_builtins.str]] = None,
                 private_endpoint: Optional[pulumi.Input[Union['InferenceDeploymentPrivateEndpointArgs', 'InferenceDeploymentPrivateEndpointArgsDict']]] = None,
                 private_ips: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InferenceDeploymentPrivateIpArgs', 'InferenceDeploymentPrivateIpArgsDict']]]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public_endpoint: Optional[pulumi.Input[Union['InferenceDeploymentPublicEndpointArgs', 'InferenceDeploymentPublicEndpointArgsDict']]] = None,
                 quantization: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        pulumi.log.warn("""InferenceDeployment is deprecated: scaleway.index/inferencedeployment.InferenceDeployment has been deprecated in favor of scaleway.inference/deployment.Deployment""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InferenceDeploymentArgs.__new__(InferenceDeploymentArgs)

            __props__.__dict__["accept_eula"] = accept_eula
            __props__.__dict__["max_size"] = max_size
            __props__.__dict__["min_size"] = min_size
            if model_id is None and not opts.urn:
                raise TypeError("Missing required property 'model_id'")
            __props__.__dict__["model_id"] = model_id
            __props__.__dict__["name"] = name
            if node_type is None and not opts.urn:
                raise TypeError("Missing required property 'node_type'")
            __props__.__dict__["node_type"] = node_type
            __props__.__dict__["private_endpoint"] = private_endpoint
            __props__.__dict__["private_ips"] = private_ips
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["public_endpoint"] = public_endpoint
            __props__.__dict__["quantization"] = quantization
            __props__.__dict__["region"] = region
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created_at"] = None
            __props__.__dict__["model_name"] = None
            __props__.__dict__["size"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
        super(InferenceDeployment, __self__).__init__(
            'scaleway:index/inferenceDeployment:InferenceDeployment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            accept_eula: Optional[pulumi.Input[_builtins.bool]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            max_size: Optional[pulumi.Input[_builtins.int]] = None,
            min_size: Optional[pulumi.Input[_builtins.int]] = None,
            model_id: Optional[pulumi.Input[_builtins.str]] = None,
            model_name: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            node_type: Optional[pulumi.Input[_builtins.str]] = None,
            private_endpoint: Optional[pulumi.Input[Union['InferenceDeploymentPrivateEndpointArgs', 'InferenceDeploymentPrivateEndpointArgsDict']]] = None,
            private_ips: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InferenceDeploymentPrivateIpArgs', 'InferenceDeploymentPrivateIpArgsDict']]]]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            public_endpoint: Optional[pulumi.Input[Union['InferenceDeploymentPublicEndpointArgs', 'InferenceDeploymentPublicEndpointArgsDict']]] = None,
            quantization: Optional[pulumi.Input[_builtins.int]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            size: Optional[pulumi.Input[_builtins.int]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None) -> 'InferenceDeployment':
        """
        Get an existing InferenceDeployment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] accept_eula: Some models (e.g Meta Llama) require end-user license agreements. Set `true` to accept.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the deployment.
        :param pulumi.Input[_builtins.int] max_size: The maximum size of the pool.
        :param pulumi.Input[_builtins.int] min_size: The minimum size of the pool.
        :param pulumi.Input[_builtins.str] model_id: The model id used for the deployment.
        :param pulumi.Input[_builtins.str] model_name: The model name used for the deployment. Model names can be found in Console or using Scaleway's CLI (`scw inference model list`)
        :param pulumi.Input[_builtins.str] name: The deployment name.
        :param pulumi.Input[_builtins.str] node_type: The node type to use for the deployment. Node types can be found using Scaleway's CLI (`scw inference node-type list`)
        :param pulumi.Input[Union['InferenceDeploymentPrivateEndpointArgs', 'InferenceDeploymentPrivateEndpointArgsDict']] private_endpoint: Configuration of the deployment's private endpoint.
        :param pulumi.Input[Sequence[pulumi.Input[Union['InferenceDeploymentPrivateIpArgs', 'InferenceDeploymentPrivateIpArgsDict']]]] private_ips: The private IPv4 address associated with the deployment.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the deployment is associated with.
        :param pulumi.Input[Union['InferenceDeploymentPublicEndpointArgs', 'InferenceDeploymentPublicEndpointArgsDict']] public_endpoint: Configuration of the deployment's public endpoint.
        :param pulumi.Input[_builtins.int] quantization: The number of bits each model parameter should be quantized to
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the deployment is created.
        :param pulumi.Input[_builtins.int] size: The size of the pool.
        :param pulumi.Input[_builtins.str] status: The status of the deployment.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the deployment.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the deployment.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InferenceDeploymentState.__new__(_InferenceDeploymentState)

        __props__.__dict__["accept_eula"] = accept_eula
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["max_size"] = max_size
        __props__.__dict__["min_size"] = min_size
        __props__.__dict__["model_id"] = model_id
        __props__.__dict__["model_name"] = model_name
        __props__.__dict__["name"] = name
        __props__.__dict__["node_type"] = node_type
        __props__.__dict__["private_endpoint"] = private_endpoint
        __props__.__dict__["private_ips"] = private_ips
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["public_endpoint"] = public_endpoint
        __props__.__dict__["quantization"] = quantization
        __props__.__dict__["region"] = region
        __props__.__dict__["size"] = size
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        return InferenceDeployment(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="acceptEula")
    def accept_eula(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Some models (e.g Meta Llama) require end-user license agreements. Set `true` to accept.
        """
        return pulumi.get(self, "accept_eula")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the creation of the deployment.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="maxSize")
    def max_size(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The maximum size of the pool.
        """
        return pulumi.get(self, "max_size")

    @_builtins.property
    @pulumi.getter(name="minSize")
    def min_size(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The minimum size of the pool.
        """
        return pulumi.get(self, "min_size")

    @_builtins.property
    @pulumi.getter(name="modelId")
    def model_id(self) -> pulumi.Output[_builtins.str]:
        """
        The model id used for the deployment.
        """
        return pulumi.get(self, "model_id")

    @_builtins.property
    @pulumi.getter(name="modelName")
    def model_name(self) -> pulumi.Output[_builtins.str]:
        """
        The model name used for the deployment. Model names can be found in Console or using Scaleway's CLI (`scw inference model list`)
        """
        return pulumi.get(self, "model_name")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The deployment name.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> pulumi.Output[_builtins.str]:
        """
        The node type to use for the deployment. Node types can be found using Scaleway's CLI (`scw inference node-type list`)
        """
        return pulumi.get(self, "node_type")

    @_builtins.property
    @pulumi.getter(name="privateEndpoint")
    def private_endpoint(self) -> pulumi.Output[Optional['outputs.InferenceDeploymentPrivateEndpoint']]:
        """
        Configuration of the deployment's private endpoint.
        """
        return pulumi.get(self, "private_endpoint")

    @_builtins.property
    @pulumi.getter(name="privateIps")
    def private_ips(self) -> pulumi.Output[Sequence['outputs.InferenceDeploymentPrivateIp']]:
        """
        The private IPv4 address associated with the deployment.
        """
        return pulumi.get(self, "private_ips")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the project the deployment is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="publicEndpoint")
    def public_endpoint(self) -> pulumi.Output[Optional['outputs.InferenceDeploymentPublicEndpoint']]:
        """
        Configuration of the deployment's public endpoint.
        """
        return pulumi.get(self, "public_endpoint")

    @_builtins.property
    @pulumi.getter
    def quantization(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The number of bits each model parameter should be quantized to
        """
        return pulumi.get(self, "quantization")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region in which the deployment is created.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def size(self) -> pulumi.Output[_builtins.int]:
        """
        The size of the pool.
        """
        return pulumi.get(self, "size")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the deployment.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The tags associated with the deployment.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the last update of the deployment.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ClusterArgs', 'Cluster']

@pulumi.input_type
class ClusterArgs:
    def __init__(__self__, *,
                 node_amount: pulumi.Input[_builtins.int],
                 node_type: pulumi.Input[_builtins.str],
                 version: pulumi.Input[_builtins.str],
                 volume_size_in_gb: pulumi.Input[_builtins.int],
                 volume_type: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network: Optional[pulumi.Input['ClusterPrivateNetworkArgs']] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Cluster resource.
        :param pulumi.Input[_builtins.int] node_amount: Number of nodes in the cluster. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] node_type: Node type to use for the cluster. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] version: Kafka version to use (e.g., "3.9.0"). Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.int] volume_size_in_gb: Volume size in GB. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] volume_type: Type of volume where data is stored (e.g., "sbs_5k", "sbs_15k"). Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] name: Name of the Kafka cluster.
        :param pulumi.Input[_builtins.str] password: Password for the Kafka user. Required if `user_name` is specified. Changing this forces recreation of the cluster.
        :param pulumi.Input['ClusterPrivateNetworkArgs'] private_network: Private network endpoint information.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the cluster is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the cluster should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: List of tags to apply to the cluster.
        :param pulumi.Input[_builtins.str] user_name: Username for the Kafka user. If not specified, no user will be created. Changing this forces recreation of the cluster.
        """
        pulumi.set(__self__, "node_amount", node_amount)
        pulumi.set(__self__, "node_type", node_type)
        pulumi.set(__self__, "version", version)
        pulumi.set(__self__, "volume_size_in_gb", volume_size_in_gb)
        pulumi.set(__self__, "volume_type", volume_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if private_network is not None:
            pulumi.set(__self__, "private_network", private_network)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @_builtins.property
    @pulumi.getter(name="nodeAmount")
    def node_amount(self) -> pulumi.Input[_builtins.int]:
        """
        Number of nodes in the cluster. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "node_amount")

    @node_amount.setter
    def node_amount(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "node_amount", value)

    @_builtins.property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> pulumi.Input[_builtins.str]:
        """
        Node type to use for the cluster. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "node_type")

    @node_type.setter
    def node_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "node_type", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> pulumi.Input[_builtins.str]:
        """
        Kafka version to use (e.g., "3.9.0"). Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "version", value)

    @_builtins.property
    @pulumi.getter(name="volumeSizeInGb")
    def volume_size_in_gb(self) -> pulumi.Input[_builtins.int]:
        """
        Volume size in GB. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "volume_size_in_gb")

    @volume_size_in_gb.setter
    def volume_size_in_gb(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "volume_size_in_gb", value)

    @_builtins.property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of volume where data is stored (e.g., "sbs_5k", "sbs_15k"). Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "volume_type")

    @volume_type.setter
    def volume_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "volume_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Kafka cluster.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password for the Kafka user. Required if `user_name` is specified. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter(name="privateNetwork")
    def private_network(self) -> Optional[pulumi.Input['ClusterPrivateNetworkArgs']]:
        """
        Private network endpoint information.
        """
        return pulumi.get(self, "private_network")

    @private_network.setter
    def private_network(self, value: Optional[pulumi.Input['ClusterPrivateNetworkArgs']]):
        pulumi.set(self, "private_network", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the cluster is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the cluster should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of tags to apply to the cluster.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username for the Kafka user. If not specified, no user will be created. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name", value)


@pulumi.input_type
class _ClusterState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_amount: Optional[pulumi.Input[_builtins.int]] = None,
                 node_type: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network: Optional[pulumi.Input['ClusterPrivateNetworkArgs']] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public_networks: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterPublicNetworkArgs']]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 volume_size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
                 volume_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Cluster resources.
        :param pulumi.Input[_builtins.str] created_at: Date and time of cluster creation (RFC 3339 format).
        :param pulumi.Input[_builtins.str] name: Name of the Kafka cluster.
        :param pulumi.Input[_builtins.int] node_amount: Number of nodes in the cluster. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] node_type: Node type to use for the cluster. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] password: Password for the Kafka user. Required if `user_name` is specified. Changing this forces recreation of the cluster.
        :param pulumi.Input['ClusterPrivateNetworkArgs'] private_network: Private network endpoint information.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the cluster is associated with.
        :param pulumi.Input[Sequence[pulumi.Input['ClusterPublicNetworkArgs']]] public_networks: Public endpoint information.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the cluster should be created.
        :param pulumi.Input[_builtins.str] status: The status of the cluster (e.g., "ready", "creating", "configuring").
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: List of tags to apply to the cluster.
        :param pulumi.Input[_builtins.str] updated_at: Date and time of cluster last update (RFC 3339 format).
        :param pulumi.Input[_builtins.str] user_name: Username for the Kafka user. If not specified, no user will be created. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] version: Kafka version to use (e.g., "3.9.0"). Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.int] volume_size_in_gb: Volume size in GB. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] volume_type: Type of volume where data is stored (e.g., "sbs_5k", "sbs_15k"). Changing this forces recreation of the cluster.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_amount is not None:
            pulumi.set(__self__, "node_amount", node_amount)
        if node_type is not None:
            pulumi.set(__self__, "node_type", node_type)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if private_network is not None:
            pulumi.set(__self__, "private_network", private_network)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if public_networks is not None:
            pulumi.set(__self__, "public_networks", public_networks)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)
        if version is not None:
            pulumi.set(__self__, "version", version)
        if volume_size_in_gb is not None:
            pulumi.set(__self__, "volume_size_in_gb", volume_size_in_gb)
        if volume_type is not None:
            pulumi.set(__self__, "volume_type", volume_type)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Date and time of cluster creation (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Kafka cluster.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="nodeAmount")
    def node_amount(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of nodes in the cluster. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "node_amount")

    @node_amount.setter
    def node_amount(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "node_amount", value)

    @_builtins.property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Node type to use for the cluster. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "node_type")

    @node_type.setter
    def node_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "node_type", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password for the Kafka user. Required if `user_name` is specified. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter(name="privateNetwork")
    def private_network(self) -> Optional[pulumi.Input['ClusterPrivateNetworkArgs']]:
        """
        Private network endpoint information.
        """
        return pulumi.get(self, "private_network")

    @private_network.setter
    def private_network(self, value: Optional[pulumi.Input['ClusterPrivateNetworkArgs']]):
        pulumi.set(self, "private_network", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the cluster is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="publicNetworks")
    def public_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterPublicNetworkArgs']]]]:
        """
        Public endpoint information.
        """
        return pulumi.get(self, "public_networks")

    @public_networks.setter
    def public_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterPublicNetworkArgs']]]]):
        pulumi.set(self, "public_networks", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the cluster should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the cluster (e.g., "ready", "creating", "configuring").
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of tags to apply to the cluster.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Date and time of cluster last update (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username for the Kafka user. If not specified, no user will be created. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Kafka version to use (e.g., "3.9.0"). Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version", value)

    @_builtins.property
    @pulumi.getter(name="volumeSizeInGb")
    def volume_size_in_gb(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Volume size in GB. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "volume_size_in_gb")

    @volume_size_in_gb.setter
    def volume_size_in_gb(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "volume_size_in_gb", value)

    @_builtins.property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of volume where data is stored (e.g., "sbs_5k", "sbs_15k"). Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "volume_type")

    @volume_type.setter
    def volume_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "volume_type", value)


@pulumi.type_token("scaleway:kafka/cluster:Cluster")
class Cluster(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_amount: Optional[pulumi.Input[_builtins.int]] = None,
                 node_type: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network: Optional[pulumi.Input[Union['ClusterPrivateNetworkArgs', 'ClusterPrivateNetworkArgsDict']]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 volume_size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
                 volume_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Kafka clusters.
        For more information refer to the [product documentation](https://www.scaleway.com/en/docs/managed-services/kafka/).

        > **Important:** The Kafka product is currently in Public Beta.

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.network.Vpc("main",
            region="fr-par",
            name="my-vpc")
        pn = scaleway.network.PrivateNetwork("pn",
            name="my-private-network",
            region="fr-par",
            vpc_id=main.id)
        main_cluster = scaleway.kafka.Cluster("main",
            name="my-kafka-cluster",
            version="3.9.0",
            node_amount=1,
            node_type="KAFK-PLAY-NANO",
            volume_type="sbs_5k",
            volume_size_in_gb=10,
            user_name="admin",
            password="thiZ_is_v&ry_s3cret",
            private_network={
                "pn_id": pn.id,
            })
        ```

        ### With Tags

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.network.Vpc("main",
            region="fr-par",
            name="my-vpc")
        pn = scaleway.network.PrivateNetwork("pn",
            name="my-private-network",
            region="fr-par",
            vpc_id=main.id)
        main_cluster = scaleway.kafka.Cluster("main",
            name="my-kafka-cluster",
            version="3.9.0",
            node_amount=1,
            node_type="KAFK-PLAY-NANO",
            volume_type="sbs_5k",
            volume_size_in_gb=10,
            user_name="admin",
            password="thiZ_is_v&ry_s3cret",
            tags=[
                "production",
                "messaging",
            ],
            private_network={
                "pn_id": pn.id,
            })
        ```

        ## Import

        Kafka clusters can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:kafka/cluster:Cluster main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] name: Name of the Kafka cluster.
        :param pulumi.Input[_builtins.int] node_amount: Number of nodes in the cluster. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] node_type: Node type to use for the cluster. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] password: Password for the Kafka user. Required if `user_name` is specified. Changing this forces recreation of the cluster.
        :param pulumi.Input[Union['ClusterPrivateNetworkArgs', 'ClusterPrivateNetworkArgsDict']] private_network: Private network endpoint information.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the cluster is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the cluster should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: List of tags to apply to the cluster.
        :param pulumi.Input[_builtins.str] user_name: Username for the Kafka user. If not specified, no user will be created. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] version: Kafka version to use (e.g., "3.9.0"). Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.int] volume_size_in_gb: Volume size in GB. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] volume_type: Type of volume where data is stored (e.g., "sbs_5k", "sbs_15k"). Changing this forces recreation of the cluster.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClusterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Kafka clusters.
        For more information refer to the [product documentation](https://www.scaleway.com/en/docs/managed-services/kafka/).

        > **Important:** The Kafka product is currently in Public Beta.

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.network.Vpc("main",
            region="fr-par",
            name="my-vpc")
        pn = scaleway.network.PrivateNetwork("pn",
            name="my-private-network",
            region="fr-par",
            vpc_id=main.id)
        main_cluster = scaleway.kafka.Cluster("main",
            name="my-kafka-cluster",
            version="3.9.0",
            node_amount=1,
            node_type="KAFK-PLAY-NANO",
            volume_type="sbs_5k",
            volume_size_in_gb=10,
            user_name="admin",
            password="thiZ_is_v&ry_s3cret",
            private_network={
                "pn_id": pn.id,
            })
        ```

        ### With Tags

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.network.Vpc("main",
            region="fr-par",
            name="my-vpc")
        pn = scaleway.network.PrivateNetwork("pn",
            name="my-private-network",
            region="fr-par",
            vpc_id=main.id)
        main_cluster = scaleway.kafka.Cluster("main",
            name="my-kafka-cluster",
            version="3.9.0",
            node_amount=1,
            node_type="KAFK-PLAY-NANO",
            volume_type="sbs_5k",
            volume_size_in_gb=10,
            user_name="admin",
            password="thiZ_is_v&ry_s3cret",
            tags=[
                "production",
                "messaging",
            ],
            private_network={
                "pn_id": pn.id,
            })
        ```

        ## Import

        Kafka clusters can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:kafka/cluster:Cluster main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param ClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_amount: Optional[pulumi.Input[_builtins.int]] = None,
                 node_type: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network: Optional[pulumi.Input[Union['ClusterPrivateNetworkArgs', 'ClusterPrivateNetworkArgsDict']]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 volume_size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
                 volume_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClusterArgs.__new__(ClusterArgs)

            __props__.__dict__["name"] = name
            if node_amount is None and not opts.urn:
                raise TypeError("Missing required property 'node_amount'")
            __props__.__dict__["node_amount"] = node_amount
            if node_type is None and not opts.urn:
                raise TypeError("Missing required property 'node_type'")
            __props__.__dict__["node_type"] = node_type
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["private_network"] = private_network
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["region"] = region
            __props__.__dict__["tags"] = tags
            __props__.__dict__["user_name"] = user_name
            if version is None and not opts.urn:
                raise TypeError("Missing required property 'version'")
            __props__.__dict__["version"] = version
            if volume_size_in_gb is None and not opts.urn:
                raise TypeError("Missing required property 'volume_size_in_gb'")
            __props__.__dict__["volume_size_in_gb"] = volume_size_in_gb
            if volume_type is None and not opts.urn:
                raise TypeError("Missing required property 'volume_type'")
            __props__.__dict__["volume_type"] = volume_type
            __props__.__dict__["created_at"] = None
            __props__.__dict__["public_networks"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Cluster, __self__).__init__(
            'scaleway:kafka/cluster:Cluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            node_amount: Optional[pulumi.Input[_builtins.int]] = None,
            node_type: Optional[pulumi.Input[_builtins.str]] = None,
            password: Optional[pulumi.Input[_builtins.str]] = None,
            private_network: Optional[pulumi.Input[Union['ClusterPrivateNetworkArgs', 'ClusterPrivateNetworkArgsDict']]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            public_networks: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClusterPublicNetworkArgs', 'ClusterPublicNetworkArgsDict']]]]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None,
            user_name: Optional[pulumi.Input[_builtins.str]] = None,
            version: Optional[pulumi.Input[_builtins.str]] = None,
            volume_size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
            volume_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'Cluster':
        """
        Get an existing Cluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_at: Date and time of cluster creation (RFC 3339 format).
        :param pulumi.Input[_builtins.str] name: Name of the Kafka cluster.
        :param pulumi.Input[_builtins.int] node_amount: Number of nodes in the cluster. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] node_type: Node type to use for the cluster. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] password: Password for the Kafka user. Required if `user_name` is specified. Changing this forces recreation of the cluster.
        :param pulumi.Input[Union['ClusterPrivateNetworkArgs', 'ClusterPrivateNetworkArgsDict']] private_network: Private network endpoint information.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the cluster is associated with.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ClusterPublicNetworkArgs', 'ClusterPublicNetworkArgsDict']]]] public_networks: Public endpoint information.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the cluster should be created.
        :param pulumi.Input[_builtins.str] status: The status of the cluster (e.g., "ready", "creating", "configuring").
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: List of tags to apply to the cluster.
        :param pulumi.Input[_builtins.str] updated_at: Date and time of cluster last update (RFC 3339 format).
        :param pulumi.Input[_builtins.str] user_name: Username for the Kafka user. If not specified, no user will be created. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] version: Kafka version to use (e.g., "3.9.0"). Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.int] volume_size_in_gb: Volume size in GB. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] volume_type: Type of volume where data is stored (e.g., "sbs_5k", "sbs_15k"). Changing this forces recreation of the cluster.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClusterState.__new__(_ClusterState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["name"] = name
        __props__.__dict__["node_amount"] = node_amount
        __props__.__dict__["node_type"] = node_type
        __props__.__dict__["password"] = password
        __props__.__dict__["private_network"] = private_network
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["public_networks"] = public_networks
        __props__.__dict__["region"] = region
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["user_name"] = user_name
        __props__.__dict__["version"] = version
        __props__.__dict__["volume_size_in_gb"] = volume_size_in_gb
        __props__.__dict__["volume_type"] = volume_type
        return Cluster(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        Date and time of cluster creation (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the Kafka cluster.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="nodeAmount")
    def node_amount(self) -> pulumi.Output[_builtins.int]:
        """
        Number of nodes in the cluster. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "node_amount")

    @_builtins.property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> pulumi.Output[_builtins.str]:
        """
        Node type to use for the cluster. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "node_type")

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Password for the Kafka user. Required if `user_name` is specified. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter(name="privateNetwork")
    def private_network(self) -> pulumi.Output[Optional['outputs.ClusterPrivateNetwork']]:
        """
        Private network endpoint information.
        """
        return pulumi.get(self, "private_network")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the project the cluster is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="publicNetworks")
    def public_networks(self) -> pulumi.Output[Sequence['outputs.ClusterPublicNetwork']]:
        """
        Public endpoint information.
        """
        return pulumi.get(self, "public_networks")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region in which the cluster should be created.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the cluster (e.g., "ready", "creating", "configuring").
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of tags to apply to the cluster.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        Date and time of cluster last update (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Username for the Kafka user. If not specified, no user will be created. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "user_name")

    @_builtins.property
    @pulumi.getter
    def version(self) -> pulumi.Output[_builtins.str]:
        """
        Kafka version to use (e.g., "3.9.0"). Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "version")

    @_builtins.property
    @pulumi.getter(name="volumeSizeInGb")
    def volume_size_in_gb(self) -> pulumi.Output[_builtins.int]:
        """
        Volume size in GB. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "volume_size_in_gb")

    @_builtins.property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of volume where data is stored (e.g., "sbs_5k", "sbs_15k"). Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "volume_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'BackendStageLbBackendConfig',
    'BackendStageLbBackendConfigLbConfig',
    'BackendStageS3BackendConfig',
    'CacheStagePurgeRequest',
    'RouteStageRule',
    'RouteStageRuleRuleHttpMatch',
    'RouteStageRuleRuleHttpMatchPathFilter',
    'TlsStageSecret',
    'GetBackendStageLbBackendConfigResult',
    'GetBackendStageLbBackendConfigLbConfigResult',
    'GetBackendStageS3BackendConfigResult',
    'GetCacheStagePurgeRequestResult',
    'GetRouteStageRuleResult',
    'GetRouteStageRuleRuleHttpMatchResult',
    'GetRouteStageRuleRuleHttpMatchPathFilterResult',
    'GetTlsStageSecretResult',
]

@pulumi.output_type
class BackendStageLbBackendConfig(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "lbConfig":
            suggest = "lb_config"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackendStageLbBackendConfig. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackendStageLbBackendConfig.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackendStageLbBackendConfig.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 lb_config: Optional['outputs.BackendStageLbBackendConfigLbConfig'] = None):
        """
        :param 'BackendStageLbBackendConfigLbConfigArgs' lb_config: The Load Balancer config.
        """
        if lb_config is not None:
            pulumi.set(__self__, "lb_config", lb_config)

    @_builtins.property
    @pulumi.getter(name="lbConfig")
    def lb_config(self) -> Optional['outputs.BackendStageLbBackendConfigLbConfig']:
        """
        The Load Balancer config.
        """
        return pulumi.get(self, "lb_config")


@pulumi.output_type
class BackendStageLbBackendConfigLbConfig(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "domainName":
            suggest = "domain_name"
        elif key == "frontendId":
            suggest = "frontend_id"
        elif key == "hasWebsocket":
            suggest = "has_websocket"
        elif key == "isSsl":
            suggest = "is_ssl"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackendStageLbBackendConfigLbConfig. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackendStageLbBackendConfigLbConfig.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackendStageLbBackendConfigLbConfig.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 domain_name: Optional[_builtins.str] = None,
                 frontend_id: Optional[_builtins.str] = None,
                 has_websocket: Optional[_builtins.bool] = None,
                 id: Optional[_builtins.str] = None,
                 is_ssl: Optional[_builtins.bool] = None,
                 zone: Optional[_builtins.str] = None):
        """
        :param _builtins.str domain_name: The Fully Qualified Domain Name (in the format subdomain.example.com) to use in HTTP requests sent towards your Load Balancer.
        :param _builtins.str frontend_id: The ID of the frontend.
        :param _builtins.bool has_websocket: Defines whether to forward websocket requests to the load balancer.
        :param _builtins.str id: The ID of the Load Balancer.
        :param _builtins.bool is_ssl: Defines whether the Load Balancer's frontend handles SSL connections.
        :param _builtins.str zone: `zone`) The zone of the Load Balancer.
        """
        if domain_name is not None:
            pulumi.set(__self__, "domain_name", domain_name)
        if frontend_id is not None:
            pulumi.set(__self__, "frontend_id", frontend_id)
        if has_websocket is not None:
            pulumi.set(__self__, "has_websocket", has_websocket)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_ssl is not None:
            pulumi.set(__self__, "is_ssl", is_ssl)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> Optional[_builtins.str]:
        """
        The Fully Qualified Domain Name (in the format subdomain.example.com) to use in HTTP requests sent towards your Load Balancer.
        """
        return pulumi.get(self, "domain_name")

    @_builtins.property
    @pulumi.getter(name="frontendId")
    def frontend_id(self) -> Optional[_builtins.str]:
        """
        The ID of the frontend.
        """
        return pulumi.get(self, "frontend_id")

    @_builtins.property
    @pulumi.getter(name="hasWebsocket")
    def has_websocket(self) -> Optional[_builtins.bool]:
        """
        Defines whether to forward websocket requests to the load balancer.
        """
        return pulumi.get(self, "has_websocket")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        The ID of the Load Balancer.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isSsl")
    def is_ssl(self) -> Optional[_builtins.bool]:
        """
        Defines whether the Load Balancer's frontend handles SSL connections.
        """
        return pulumi.get(self, "is_ssl")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[_builtins.str]:
        """
        `zone`) The zone of the Load Balancer.
        """
        return pulumi.get(self, "zone")


@pulumi.output_type
class BackendStageS3BackendConfig(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "bucketName":
            suggest = "bucket_name"
        elif key == "bucketRegion":
            suggest = "bucket_region"
        elif key == "isWebsite":
            suggest = "is_website"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackendStageS3BackendConfig. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackendStageS3BackendConfig.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackendStageS3BackendConfig.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 bucket_name: Optional[_builtins.str] = None,
                 bucket_region: Optional[_builtins.str] = None,
                 is_website: Optional[_builtins.bool] = None):
        """
        :param _builtins.str bucket_name: The name of the Bucket.
        :param _builtins.str bucket_region: The region of the Bucket.
        :param _builtins.bool is_website: Defines whether the bucket website feature is enabled.
        """
        if bucket_name is not None:
            pulumi.set(__self__, "bucket_name", bucket_name)
        if bucket_region is not None:
            pulumi.set(__self__, "bucket_region", bucket_region)
        if is_website is not None:
            pulumi.set(__self__, "is_website", is_website)

    @_builtins.property
    @pulumi.getter(name="bucketName")
    def bucket_name(self) -> Optional[_builtins.str]:
        """
        The name of the Bucket.
        """
        return pulumi.get(self, "bucket_name")

    @_builtins.property
    @pulumi.getter(name="bucketRegion")
    def bucket_region(self) -> Optional[_builtins.str]:
        """
        The region of the Bucket.
        """
        return pulumi.get(self, "bucket_region")

    @_builtins.property
    @pulumi.getter(name="isWebsite")
    def is_website(self) -> Optional[_builtins.bool]:
        """
        Defines whether the bucket website feature is enabled.
        """
        return pulumi.get(self, "is_website")


@pulumi.output_type
class CacheStagePurgeRequest(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "pipelineId":
            suggest = "pipeline_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in CacheStagePurgeRequest. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        CacheStagePurgeRequest.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        CacheStagePurgeRequest.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 all: Optional[_builtins.bool] = None,
                 assets: Optional[Sequence[_builtins.str]] = None,
                 pipeline_id: Optional[_builtins.str] = None):
        """
        :param _builtins.bool all: Defines whether to purge all content.
        :param Sequence[_builtins.str] assets: The list of asserts to purge.
        :param _builtins.str pipeline_id: The pipeline ID in which the purge request will be created.
        """
        if all is not None:
            pulumi.set(__self__, "all", all)
        if assets is not None:
            pulumi.set(__self__, "assets", assets)
        if pipeline_id is not None:
            pulumi.set(__self__, "pipeline_id", pipeline_id)

    @_builtins.property
    @pulumi.getter
    def all(self) -> Optional[_builtins.bool]:
        """
        Defines whether to purge all content.
        """
        return pulumi.get(self, "all")

    @_builtins.property
    @pulumi.getter
    def assets(self) -> Optional[Sequence[_builtins.str]]:
        """
        The list of asserts to purge.
        """
        return pulumi.get(self, "assets")

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> Optional[_builtins.str]:
        """
        The pipeline ID in which the purge request will be created.
        """
        return pulumi.get(self, "pipeline_id")


@pulumi.output_type
class RouteStageRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "backendStageId":
            suggest = "backend_stage_id"
        elif key == "ruleHttpMatch":
            suggest = "rule_http_match"
        elif key == "wafStageId":
            suggest = "waf_stage_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RouteStageRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RouteStageRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RouteStageRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 backend_stage_id: Optional[_builtins.str] = None,
                 rule_http_match: Optional['outputs.RouteStageRuleRuleHttpMatch'] = None,
                 waf_stage_id: Optional[_builtins.str] = None):
        """
        :param _builtins.str backend_stage_id: The ID of the backend stage that requests matching the rule should be forwarded to. Conflicts with `waf_stage_id` within the same rule.
        :param 'RouteStageRuleRuleHttpMatchArgs' rule_http_match: The rule condition to be matched. Requests matching the condition defined here will be forwarded to the stage specified by `backend_stage_id` or `waf_stage_id`. Requests that do not match will be checked by the next rule's condition.
        :param _builtins.str waf_stage_id: The ID of the WAF stage that requests matching the rule should be forwarded to. Conflicts with `backend_stage_id` within the same rule.
        """
        if backend_stage_id is not None:
            pulumi.set(__self__, "backend_stage_id", backend_stage_id)
        if rule_http_match is not None:
            pulumi.set(__self__, "rule_http_match", rule_http_match)
        if waf_stage_id is not None:
            pulumi.set(__self__, "waf_stage_id", waf_stage_id)

    @_builtins.property
    @pulumi.getter(name="backendStageId")
    def backend_stage_id(self) -> Optional[_builtins.str]:
        """
        The ID of the backend stage that requests matching the rule should be forwarded to. Conflicts with `waf_stage_id` within the same rule.
        """
        return pulumi.get(self, "backend_stage_id")

    @_builtins.property
    @pulumi.getter(name="ruleHttpMatch")
    def rule_http_match(self) -> Optional['outputs.RouteStageRuleRuleHttpMatch']:
        """
        The rule condition to be matched. Requests matching the condition defined here will be forwarded to the stage specified by `backend_stage_id` or `waf_stage_id`. Requests that do not match will be checked by the next rule's condition.
        """
        return pulumi.get(self, "rule_http_match")

    @_builtins.property
    @pulumi.getter(name="wafStageId")
    def waf_stage_id(self) -> Optional[_builtins.str]:
        """
        The ID of the WAF stage that requests matching the rule should be forwarded to. Conflicts with `backend_stage_id` within the same rule.
        """
        return pulumi.get(self, "waf_stage_id")


@pulumi.output_type
class RouteStageRuleRuleHttpMatch(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "methodFilters":
            suggest = "method_filters"
        elif key == "pathFilter":
            suggest = "path_filter"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RouteStageRuleRuleHttpMatch. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RouteStageRuleRuleHttpMatch.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RouteStageRuleRuleHttpMatch.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 method_filters: Optional[Sequence[_builtins.str]] = None,
                 path_filter: Optional['outputs.RouteStageRuleRuleHttpMatchPathFilter'] = None):
        """
        :param Sequence[_builtins.str] method_filters: HTTP methods to filter for. A request using any of these methods will be considered to match the rule. Possible values are `get`, `post`, `put`, `patch`, `delete`, `head`, `options`. All methods will match if none is provided.
        :param 'RouteStageRuleRuleHttpMatchPathFilterArgs' path_filter: HTTP URL path to filter for. A request whose path matches the given filter will be considered to match the rule. All paths will match if none is provided.
        """
        if method_filters is not None:
            pulumi.set(__self__, "method_filters", method_filters)
        if path_filter is not None:
            pulumi.set(__self__, "path_filter", path_filter)

    @_builtins.property
    @pulumi.getter(name="methodFilters")
    def method_filters(self) -> Optional[Sequence[_builtins.str]]:
        """
        HTTP methods to filter for. A request using any of these methods will be considered to match the rule. Possible values are `get`, `post`, `put`, `patch`, `delete`, `head`, `options`. All methods will match if none is provided.
        """
        return pulumi.get(self, "method_filters")

    @_builtins.property
    @pulumi.getter(name="pathFilter")
    def path_filter(self) -> Optional['outputs.RouteStageRuleRuleHttpMatchPathFilter']:
        """
        HTTP URL path to filter for. A request whose path matches the given filter will be considered to match the rule. All paths will match if none is provided.
        """
        return pulumi.get(self, "path_filter")


@pulumi.output_type
class RouteStageRuleRuleHttpMatchPathFilter(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "pathFilterType":
            suggest = "path_filter_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RouteStageRuleRuleHttpMatchPathFilter. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RouteStageRuleRuleHttpMatchPathFilter.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RouteStageRuleRuleHttpMatchPathFilter.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 path_filter_type: _builtins.str,
                 value: _builtins.str):
        """
        :param _builtins.str path_filter_type: The type of filter to match for the HTTP URL path. For now, all path filters must be written in regex and use the `regex` type.
        :param _builtins.str value: The value to be matched for the HTTP URL path.
        """
        pulumi.set(__self__, "path_filter_type", path_filter_type)
        pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter(name="pathFilterType")
    def path_filter_type(self) -> _builtins.str:
        """
        The type of filter to match for the HTTP URL path. For now, all path filters must be written in regex and use the `regex` type.
        """
        return pulumi.get(self, "path_filter_type")

    @_builtins.property
    @pulumi.getter
    def value(self) -> _builtins.str:
        """
        The value to be matched for the HTTP URL path.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class TlsStageSecret(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "secretId":
            suggest = "secret_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in TlsStageSecret. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        TlsStageSecret.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        TlsStageSecret.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 region: Optional[_builtins.str] = None,
                 secret_id: Optional[_builtins.str] = None):
        """
        :param _builtins.str region: The region of the secret.
        :param _builtins.str secret_id: The ID of the Secret
        """
        if region is not None:
            pulumi.set(__self__, "region", region)
        if secret_id is not None:
            pulumi.set(__self__, "secret_id", secret_id)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        """
        The region of the secret.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="secretId")
    def secret_id(self) -> Optional[_builtins.str]:
        """
        The ID of the Secret
        """
        return pulumi.get(self, "secret_id")


@pulumi.output_type
class GetBackendStageLbBackendConfigResult(dict):
    def __init__(__self__, *,
                 lb_configs: Sequence['outputs.GetBackendStageLbBackendConfigLbConfigResult']):
        """
        :param Sequence['GetBackendStageLbBackendConfigLbConfigArgs'] lb_configs: The Load Balancer configuration
        """
        pulumi.set(__self__, "lb_configs", lb_configs)

    @_builtins.property
    @pulumi.getter(name="lbConfigs")
    def lb_configs(self) -> Sequence['outputs.GetBackendStageLbBackendConfigLbConfigResult']:
        """
        The Load Balancer configuration
        """
        return pulumi.get(self, "lb_configs")


@pulumi.output_type
class GetBackendStageLbBackendConfigLbConfigResult(dict):
    def __init__(__self__, *,
                 domain_name: _builtins.str,
                 frontend_id: _builtins.str,
                 has_websocket: _builtins.bool,
                 id: _builtins.str,
                 is_ssl: _builtins.bool,
                 zone: _builtins.str):
        """
        :param _builtins.str domain_name: Fully Qualified Domain Name (in the format subdomain.example.com) to use in HTTP requests sent towards your Load Balancer
        :param _builtins.str frontend_id: ID of the frontend linked to the Load Balancer
        :param _builtins.bool has_websocket: Defines whether to forward websocket requests to the load balancer
        :param _builtins.str id: ID of the Load Balancer
        :param _builtins.bool is_ssl: Defines whether the Load Balancer's frontend handles SSL connections
        :param _builtins.str zone: The zone you want to attach the resource to
        """
        pulumi.set(__self__, "domain_name", domain_name)
        pulumi.set(__self__, "frontend_id", frontend_id)
        pulumi.set(__self__, "has_websocket", has_websocket)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_ssl", is_ssl)
        pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> _builtins.str:
        """
        Fully Qualified Domain Name (in the format subdomain.example.com) to use in HTTP requests sent towards your Load Balancer
        """
        return pulumi.get(self, "domain_name")

    @_builtins.property
    @pulumi.getter(name="frontendId")
    def frontend_id(self) -> _builtins.str:
        """
        ID of the frontend linked to the Load Balancer
        """
        return pulumi.get(self, "frontend_id")

    @_builtins.property
    @pulumi.getter(name="hasWebsocket")
    def has_websocket(self) -> _builtins.bool:
        """
        Defines whether to forward websocket requests to the load balancer
        """
        return pulumi.get(self, "has_websocket")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        ID of the Load Balancer
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isSsl")
    def is_ssl(self) -> _builtins.bool:
        """
        Defines whether the Load Balancer's frontend handles SSL connections
        """
        return pulumi.get(self, "is_ssl")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> _builtins.str:
        """
        The zone you want to attach the resource to
        """
        return pulumi.get(self, "zone")


@pulumi.output_type
class GetBackendStageS3BackendConfigResult(dict):
    def __init__(__self__, *,
                 bucket_name: _builtins.str,
                 bucket_region: _builtins.str,
                 is_website: _builtins.bool):
        """
        :param _builtins.str bucket_name: Filter by S3 bucket name.
        :param _builtins.str bucket_region: Filter by S3 bucket region.
        :param _builtins.bool is_website: Defines whether the bucket website feature is enabled.
        """
        pulumi.set(__self__, "bucket_name", bucket_name)
        pulumi.set(__self__, "bucket_region", bucket_region)
        pulumi.set(__self__, "is_website", is_website)

    @_builtins.property
    @pulumi.getter(name="bucketName")
    def bucket_name(self) -> _builtins.str:
        """
        Filter by S3 bucket name.
        """
        return pulumi.get(self, "bucket_name")

    @_builtins.property
    @pulumi.getter(name="bucketRegion")
    def bucket_region(self) -> _builtins.str:
        """
        Filter by S3 bucket region.
        """
        return pulumi.get(self, "bucket_region")

    @_builtins.property
    @pulumi.getter(name="isWebsite")
    def is_website(self) -> _builtins.bool:
        """
        Defines whether the bucket website feature is enabled.
        """
        return pulumi.get(self, "is_website")


@pulumi.output_type
class GetCacheStagePurgeRequestResult(dict):
    def __init__(__self__, *,
                 all: _builtins.bool,
                 assets: Sequence[_builtins.str],
                 pipeline_id: _builtins.str):
        """
        :param _builtins.bool all: Defines whether to purge all content
        :param Sequence[_builtins.str] assets: The list of asserts to purge
        :param _builtins.str pipeline_id: The ID of the pipeline.
        """
        pulumi.set(__self__, "all", all)
        pulumi.set(__self__, "assets", assets)
        pulumi.set(__self__, "pipeline_id", pipeline_id)

    @_builtins.property
    @pulumi.getter
    def all(self) -> _builtins.bool:
        """
        Defines whether to purge all content
        """
        return pulumi.get(self, "all")

    @_builtins.property
    @pulumi.getter
    def assets(self) -> Sequence[_builtins.str]:
        """
        The list of asserts to purge
        """
        return pulumi.get(self, "assets")

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> _builtins.str:
        """
        The ID of the pipeline.
        """
        return pulumi.get(self, "pipeline_id")


@pulumi.output_type
class GetRouteStageRuleResult(dict):
    def __init__(__self__, *,
                 backend_stage_id: _builtins.str,
                 rule_http_matches: Sequence['outputs.GetRouteStageRuleRuleHttpMatchResult'],
                 waf_stage_id: _builtins.str):
        """
        :param _builtins.str backend_stage_id: ID of the backend stage that requests matching the rule should be forwarded to
        :param Sequence['GetRouteStageRuleRuleHttpMatchArgs'] rule_http_matches: Rule condition to be matched. Requests matching the condition defined here will be directly forwarded to the backend specified by the `backend_stage_id` field. Requests that do not match will be checked by the next rule's condition
        :param _builtins.str waf_stage_id: ID of the WAF stage that requests matching the rule should be forwarded to
        """
        pulumi.set(__self__, "backend_stage_id", backend_stage_id)
        pulumi.set(__self__, "rule_http_matches", rule_http_matches)
        pulumi.set(__self__, "waf_stage_id", waf_stage_id)

    @_builtins.property
    @pulumi.getter(name="backendStageId")
    def backend_stage_id(self) -> _builtins.str:
        """
        ID of the backend stage that requests matching the rule should be forwarded to
        """
        return pulumi.get(self, "backend_stage_id")

    @_builtins.property
    @pulumi.getter(name="ruleHttpMatches")
    def rule_http_matches(self) -> Sequence['outputs.GetRouteStageRuleRuleHttpMatchResult']:
        """
        Rule condition to be matched. Requests matching the condition defined here will be directly forwarded to the backend specified by the `backend_stage_id` field. Requests that do not match will be checked by the next rule's condition
        """
        return pulumi.get(self, "rule_http_matches")

    @_builtins.property
    @pulumi.getter(name="wafStageId")
    def waf_stage_id(self) -> _builtins.str:
        """
        ID of the WAF stage that requests matching the rule should be forwarded to
        """
        return pulumi.get(self, "waf_stage_id")


@pulumi.output_type
class GetRouteStageRuleRuleHttpMatchResult(dict):
    def __init__(__self__, *,
                 method_filters: Sequence[_builtins.str],
                 path_filters: Sequence['outputs.GetRouteStageRuleRuleHttpMatchPathFilterResult']):
        """
        :param Sequence[_builtins.str] method_filters: HTTP methods to filter for. A request using any of these methods will be considered to match the rule. Possible values are `get`, `post`, `put`, `patch`, `delete`, `head`, `options`. All methods will match if none is provided
        :param Sequence['GetRouteStageRuleRuleHttpMatchPathFilterArgs'] path_filters: HTTP URL path to filter for. A request whose path matches the given filter will be considered to match the rule. All paths will match if none is provided
        """
        pulumi.set(__self__, "method_filters", method_filters)
        pulumi.set(__self__, "path_filters", path_filters)

    @_builtins.property
    @pulumi.getter(name="methodFilters")
    def method_filters(self) -> Sequence[_builtins.str]:
        """
        HTTP methods to filter for. A request using any of these methods will be considered to match the rule. Possible values are `get`, `post`, `put`, `patch`, `delete`, `head`, `options`. All methods will match if none is provided
        """
        return pulumi.get(self, "method_filters")

    @_builtins.property
    @pulumi.getter(name="pathFilters")
    def path_filters(self) -> Sequence['outputs.GetRouteStageRuleRuleHttpMatchPathFilterResult']:
        """
        HTTP URL path to filter for. A request whose path matches the given filter will be considered to match the rule. All paths will match if none is provided
        """
        return pulumi.get(self, "path_filters")


@pulumi.output_type
class GetRouteStageRuleRuleHttpMatchPathFilterResult(dict):
    def __init__(__self__, *,
                 path_filter_type: _builtins.str,
                 value: _builtins.str):
        """
        :param _builtins.str path_filter_type: The type of filter to match for the HTTP URL path. For now, all path filters must be written in regex and use the `regex` type
        :param _builtins.str value: The value to be matched for the HTTP URL path
        """
        pulumi.set(__self__, "path_filter_type", path_filter_type)
        pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter(name="pathFilterType")
    def path_filter_type(self) -> _builtins.str:
        """
        The type of filter to match for the HTTP URL path. For now, all path filters must be written in regex and use the `regex` type
        """
        return pulumi.get(self, "path_filter_type")

    @_builtins.property
    @pulumi.getter
    def value(self) -> _builtins.str:
        """
        The value to be matched for the HTTP URL path
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetTlsStageSecretResult(dict):
    def __init__(__self__, *,
                 region: _builtins.str,
                 secret_id: _builtins.str):
        """
        :param _builtins.str region: The region you want to attach the resource to
        :param _builtins.str secret_id: Secret ID to filter for.
        """
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "secret_id", secret_id)

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The region you want to attach the resource to
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="secretId")
    def secret_id(self) -> _builtins.str:
        """
        Secret ID to filter for.
        """
        return pulumi.get(self, "secret_id")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SnsTopicSubscriptionArgs', 'SnsTopicSubscription']

@pulumi.input_type
class SnsTopicSubscriptionArgs:
    def __init__(__self__, *,
                 access_key: pulumi.Input[_builtins.str],
                 protocol: pulumi.Input[_builtins.str],
                 secret_key: pulumi.Input[_builtins.str],
                 endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 redrive_policy: Optional[pulumi.Input[_builtins.bool]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 sns_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 topic_arn: Optional[pulumi.Input[_builtins.str]] = None,
                 topic_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a SnsTopicSubscription resource.
        :param pulumi.Input[_builtins.str] access_key: The access key of the SNS credentials.
        :param pulumi.Input[_builtins.str] protocol: Protocol of the SNS topic subscription.
        :param pulumi.Input[_builtins.str] secret_key: The secret key of the SNS credentials.
        :param pulumi.Input[_builtins.str] endpoint: Endpoint of the subscription
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project in which SNS is enabled.
        :param pulumi.Input[_builtins.bool] redrive_policy: Activate JSON redrive policy.
        :param pulumi.Input[_builtins.str] region: `region`). The region
               in which SNS is enabled.
        :param pulumi.Input[_builtins.str] sns_endpoint: The endpoint of the SNS service. Can contain a {region} placeholder. Defaults to `https://sns.mnq.{region}.scaleway.com`.
        :param pulumi.Input[_builtins.str] topic_arn: The ARN of the topic. Either `topic_id` or `topic_arn` is required.
        :param pulumi.Input[_builtins.str] topic_id: The ID of the topic. Either `topic_id` or `topic_arn` is required. Conflicts with `topic_arn`.
        """
        pulumi.set(__self__, "access_key", access_key)
        pulumi.set(__self__, "protocol", protocol)
        pulumi.set(__self__, "secret_key", secret_key)
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if redrive_policy is not None:
            pulumi.set(__self__, "redrive_policy", redrive_policy)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if sns_endpoint is not None:
            pulumi.set(__self__, "sns_endpoint", sns_endpoint)
        if topic_arn is not None:
            pulumi.set(__self__, "topic_arn", topic_arn)
        if topic_id is not None:
            pulumi.set(__self__, "topic_id", topic_id)

    @_builtins.property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> pulumi.Input[_builtins.str]:
        """
        The access key of the SNS credentials.
        """
        return pulumi.get(self, "access_key")

    @access_key.setter
    def access_key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "access_key", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[_builtins.str]:
        """
        Protocol of the SNS topic subscription.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> pulumi.Input[_builtins.str]:
        """
        The secret key of the SNS credentials.
        """
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "secret_key", value)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Endpoint of the subscription
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the Project in which SNS is enabled.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="redrivePolicy")
    def redrive_policy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Activate JSON redrive policy.
        """
        return pulumi.get(self, "redrive_policy")

    @redrive_policy.setter
    def redrive_policy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "redrive_policy", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`). The region
        in which SNS is enabled.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="snsEndpoint")
    def sns_endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The endpoint of the SNS service. Can contain a {region} placeholder. Defaults to `https://sns.mnq.{region}.scaleway.com`.
        """
        return pulumi.get(self, "sns_endpoint")

    @sns_endpoint.setter
    def sns_endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sns_endpoint", value)

    @_builtins.property
    @pulumi.getter(name="topicArn")
    def topic_arn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ARN of the topic. Either `topic_id` or `topic_arn` is required.
        """
        return pulumi.get(self, "topic_arn")

    @topic_arn.setter
    def topic_arn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "topic_arn", value)

    @_builtins.property
    @pulumi.getter(name="topicId")
    def topic_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the topic. Either `topic_id` or `topic_arn` is required. Conflicts with `topic_arn`.
        """
        return pulumi.get(self, "topic_id")

    @topic_id.setter
    def topic_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "topic_id", value)


@pulumi.input_type
class _SnsTopicSubscriptionState:
    def __init__(__self__, *,
                 access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 arn: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 redrive_policy: Optional[pulumi.Input[_builtins.bool]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 sns_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 topic_arn: Optional[pulumi.Input[_builtins.str]] = None,
                 topic_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SnsTopicSubscription resources.
        :param pulumi.Input[_builtins.str] access_key: The access key of the SNS credentials.
        :param pulumi.Input[_builtins.str] arn: The ARN of the topic subscription
        :param pulumi.Input[_builtins.str] endpoint: Endpoint of the subscription
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project in which SNS is enabled.
        :param pulumi.Input[_builtins.str] protocol: Protocol of the SNS topic subscription.
        :param pulumi.Input[_builtins.bool] redrive_policy: Activate JSON redrive policy.
        :param pulumi.Input[_builtins.str] region: `region`). The region
               in which SNS is enabled.
        :param pulumi.Input[_builtins.str] secret_key: The secret key of the SNS credentials.
        :param pulumi.Input[_builtins.str] sns_endpoint: The endpoint of the SNS service. Can contain a {region} placeholder. Defaults to `https://sns.mnq.{region}.scaleway.com`.
        :param pulumi.Input[_builtins.str] topic_arn: The ARN of the topic. Either `topic_id` or `topic_arn` is required.
        :param pulumi.Input[_builtins.str] topic_id: The ID of the topic. Either `topic_id` or `topic_arn` is required. Conflicts with `topic_arn`.
        """
        if access_key is not None:
            pulumi.set(__self__, "access_key", access_key)
        if arn is not None:
            pulumi.set(__self__, "arn", arn)
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if redrive_policy is not None:
            pulumi.set(__self__, "redrive_policy", redrive_policy)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if secret_key is not None:
            pulumi.set(__self__, "secret_key", secret_key)
        if sns_endpoint is not None:
            pulumi.set(__self__, "sns_endpoint", sns_endpoint)
        if topic_arn is not None:
            pulumi.set(__self__, "topic_arn", topic_arn)
        if topic_id is not None:
            pulumi.set(__self__, "topic_id", topic_id)

    @_builtins.property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The access key of the SNS credentials.
        """
        return pulumi.get(self, "access_key")

    @access_key.setter
    def access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_key", value)

    @_builtins.property
    @pulumi.getter
    def arn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ARN of the topic subscription
        """
        return pulumi.get(self, "arn")

    @arn.setter
    def arn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "arn", value)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Endpoint of the subscription
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the Project in which SNS is enabled.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Protocol of the SNS topic subscription.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter(name="redrivePolicy")
    def redrive_policy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Activate JSON redrive policy.
        """
        return pulumi.get(self, "redrive_policy")

    @redrive_policy.setter
    def redrive_policy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "redrive_policy", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`). The region
        in which SNS is enabled.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The secret key of the SNS credentials.
        """
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_key", value)

    @_builtins.property
    @pulumi.getter(name="snsEndpoint")
    def sns_endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The endpoint of the SNS service. Can contain a {region} placeholder. Defaults to `https://sns.mnq.{region}.scaleway.com`.
        """
        return pulumi.get(self, "sns_endpoint")

    @sns_endpoint.setter
    def sns_endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sns_endpoint", value)

    @_builtins.property
    @pulumi.getter(name="topicArn")
    def topic_arn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ARN of the topic. Either `topic_id` or `topic_arn` is required.
        """
        return pulumi.get(self, "topic_arn")

    @topic_arn.setter
    def topic_arn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "topic_arn", value)

    @_builtins.property
    @pulumi.getter(name="topicId")
    def topic_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the topic. Either `topic_id` or `topic_arn` is required. Conflicts with `topic_arn`.
        """
        return pulumi.get(self, "topic_id")

    @topic_id.setter
    def topic_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "topic_id", value)


@pulumi.type_token("scaleway:mnq/snsTopicSubscription:SnsTopicSubscription")
class SnsTopicSubscription(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 redrive_policy: Optional[pulumi.Input[_builtins.bool]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 sns_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 topic_arn: Optional[pulumi.Input[_builtins.str]] = None,
                 topic_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages Scaleway Messaging and Queuing SNS topic subscriptions.
        For further information, see
        our [main documentation](https://www.scaleway.com/en/docs/messaging/reference-content/sns-overview/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        # For default project in default region
        main = scaleway.mnq.Sns("main")
        main_sns_credentials = scaleway.mnq.SnsCredentials("main",
            project_id=main.project_id,
            permissions={
                "can_manage": True,
                "can_publish": True,
                "can_receive": True,
            })
        topic = scaleway.mnq.SnsTopic("topic",
            project_id=main.project_id,
            name="my-topic",
            access_key=main_sns_credentials.access_key,
            secret_key=main_sns_credentials.secret_key)
        main_sns_topic_subscription = scaleway.mnq.SnsTopicSubscription("main",
            project_id=main.project_id,
            access_key=main_sns_credentials.access_key,
            secret_key=main_sns_credentials.secret_key,
            topic_id=topic.id,
            protocol="http",
            endpoint="http://example.com")
        ```

        ## Import

        SNS topic subscriptions can be imported using `{region}/{project-id}/{topic-name}/{subscription-id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:mnq/snsTopicSubscription:SnsTopicSubscription main fr-par/11111111111111111111111111111111/my-topic/11111111111111111111111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_key: The access key of the SNS credentials.
        :param pulumi.Input[_builtins.str] endpoint: Endpoint of the subscription
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project in which SNS is enabled.
        :param pulumi.Input[_builtins.str] protocol: Protocol of the SNS topic subscription.
        :param pulumi.Input[_builtins.bool] redrive_policy: Activate JSON redrive policy.
        :param pulumi.Input[_builtins.str] region: `region`). The region
               in which SNS is enabled.
        :param pulumi.Input[_builtins.str] secret_key: The secret key of the SNS credentials.
        :param pulumi.Input[_builtins.str] sns_endpoint: The endpoint of the SNS service. Can contain a {region} placeholder. Defaults to `https://sns.mnq.{region}.scaleway.com`.
        :param pulumi.Input[_builtins.str] topic_arn: The ARN of the topic. Either `topic_id` or `topic_arn` is required.
        :param pulumi.Input[_builtins.str] topic_id: The ID of the topic. Either `topic_id` or `topic_arn` is required. Conflicts with `topic_arn`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SnsTopicSubscriptionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Scaleway Messaging and Queuing SNS topic subscriptions.
        For further information, see
        our [main documentation](https://www.scaleway.com/en/docs/messaging/reference-content/sns-overview/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        # For default project in default region
        main = scaleway.mnq.Sns("main")
        main_sns_credentials = scaleway.mnq.SnsCredentials("main",
            project_id=main.project_id,
            permissions={
                "can_manage": True,
                "can_publish": True,
                "can_receive": True,
            })
        topic = scaleway.mnq.SnsTopic("topic",
            project_id=main.project_id,
            name="my-topic",
            access_key=main_sns_credentials.access_key,
            secret_key=main_sns_credentials.secret_key)
        main_sns_topic_subscription = scaleway.mnq.SnsTopicSubscription("main",
            project_id=main.project_id,
            access_key=main_sns_credentials.access_key,
            secret_key=main_sns_credentials.secret_key,
            topic_id=topic.id,
            protocol="http",
            endpoint="http://example.com")
        ```

        ## Import

        SNS topic subscriptions can be imported using `{region}/{project-id}/{topic-name}/{subscription-id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:mnq/snsTopicSubscription:SnsTopicSubscription main fr-par/11111111111111111111111111111111/my-topic/11111111111111111111111111111111
        ```

        :param str resource_name: The name of the resource.
        :param SnsTopicSubscriptionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SnsTopicSubscriptionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 redrive_policy: Optional[pulumi.Input[_builtins.bool]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 sns_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 topic_arn: Optional[pulumi.Input[_builtins.str]] = None,
                 topic_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SnsTopicSubscriptionArgs.__new__(SnsTopicSubscriptionArgs)

            if access_key is None and not opts.urn:
                raise TypeError("Missing required property 'access_key'")
            __props__.__dict__["access_key"] = None if access_key is None else pulumi.Output.secret(access_key)
            __props__.__dict__["endpoint"] = endpoint
            __props__.__dict__["project_id"] = project_id
            if protocol is None and not opts.urn:
                raise TypeError("Missing required property 'protocol'")
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["redrive_policy"] = redrive_policy
            __props__.__dict__["region"] = region
            if secret_key is None and not opts.urn:
                raise TypeError("Missing required property 'secret_key'")
            __props__.__dict__["secret_key"] = None if secret_key is None else pulumi.Output.secret(secret_key)
            __props__.__dict__["sns_endpoint"] = sns_endpoint
            __props__.__dict__["topic_arn"] = topic_arn
            __props__.__dict__["topic_id"] = topic_id
            __props__.__dict__["arn"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="scaleway:index/mnqSnsTopicSubscription:MnqSnsTopicSubscription")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["accessKey", "secretKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(SnsTopicSubscription, __self__).__init__(
            'scaleway:mnq/snsTopicSubscription:SnsTopicSubscription',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_key: Optional[pulumi.Input[_builtins.str]] = None,
            arn: Optional[pulumi.Input[_builtins.str]] = None,
            endpoint: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            protocol: Optional[pulumi.Input[_builtins.str]] = None,
            redrive_policy: Optional[pulumi.Input[_builtins.bool]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            secret_key: Optional[pulumi.Input[_builtins.str]] = None,
            sns_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
            topic_arn: Optional[pulumi.Input[_builtins.str]] = None,
            topic_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'SnsTopicSubscription':
        """
        Get an existing SnsTopicSubscription resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_key: The access key of the SNS credentials.
        :param pulumi.Input[_builtins.str] arn: The ARN of the topic subscription
        :param pulumi.Input[_builtins.str] endpoint: Endpoint of the subscription
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project in which SNS is enabled.
        :param pulumi.Input[_builtins.str] protocol: Protocol of the SNS topic subscription.
        :param pulumi.Input[_builtins.bool] redrive_policy: Activate JSON redrive policy.
        :param pulumi.Input[_builtins.str] region: `region`). The region
               in which SNS is enabled.
        :param pulumi.Input[_builtins.str] secret_key: The secret key of the SNS credentials.
        :param pulumi.Input[_builtins.str] sns_endpoint: The endpoint of the SNS service. Can contain a {region} placeholder. Defaults to `https://sns.mnq.{region}.scaleway.com`.
        :param pulumi.Input[_builtins.str] topic_arn: The ARN of the topic. Either `topic_id` or `topic_arn` is required.
        :param pulumi.Input[_builtins.str] topic_id: The ID of the topic. Either `topic_id` or `topic_arn` is required. Conflicts with `topic_arn`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SnsTopicSubscriptionState.__new__(_SnsTopicSubscriptionState)

        __props__.__dict__["access_key"] = access_key
        __props__.__dict__["arn"] = arn
        __props__.__dict__["endpoint"] = endpoint
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["redrive_policy"] = redrive_policy
        __props__.__dict__["region"] = region
        __props__.__dict__["secret_key"] = secret_key
        __props__.__dict__["sns_endpoint"] = sns_endpoint
        __props__.__dict__["topic_arn"] = topic_arn
        __props__.__dict__["topic_id"] = topic_id
        return SnsTopicSubscription(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> pulumi.Output[_builtins.str]:
        """
        The access key of the SNS credentials.
        """
        return pulumi.get(self, "access_key")

    @_builtins.property
    @pulumi.getter
    def arn(self) -> pulumi.Output[_builtins.str]:
        """
        The ARN of the topic subscription
        """
        return pulumi.get(self, "arn")

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Endpoint of the subscription
        """
        return pulumi.get(self, "endpoint")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the Project in which SNS is enabled.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[_builtins.str]:
        """
        Protocol of the SNS topic subscription.
        """
        return pulumi.get(self, "protocol")

    @_builtins.property
    @pulumi.getter(name="redrivePolicy")
    def redrive_policy(self) -> pulumi.Output[_builtins.bool]:
        """
        Activate JSON redrive policy.
        """
        return pulumi.get(self, "redrive_policy")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`). The region
        in which SNS is enabled.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> pulumi.Output[_builtins.str]:
        """
        The secret key of the SNS credentials.
        """
        return pulumi.get(self, "secret_key")

    @_builtins.property
    @pulumi.getter(name="snsEndpoint")
    def sns_endpoint(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The endpoint of the SNS service. Can contain a {region} placeholder. Defaults to `https://sns.mnq.{region}.scaleway.com`.
        """
        return pulumi.get(self, "sns_endpoint")

    @_builtins.property
    @pulumi.getter(name="topicArn")
    def topic_arn(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The ARN of the topic. Either `topic_id` or `topic_arn` is required.
        """
        return pulumi.get(self, "topic_arn")

    @_builtins.property
    @pulumi.getter(name="topicId")
    def topic_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The ID of the topic. Either `topic_id` or `topic_arn` is required. Conflicts with `topic_arn`.
        """
        return pulumi.get(self, "topic_id")

